# pnap-tag-api
Tags are case-sensitive key-value pairs that simplify resource management. The Tag Manager API allows you to create
and manage such tags to later assign them to related resources in your Bare Metal Cloud (through the respective
resource apis) in order to group and categorize them.<br>
<br>
<span class='pnap-api-knowledge-base-link'>
Knowledge base articles to help you can be found
<a href='https://phoenixnap.com/kb/bmc-server-management-via-api#server-tag-manager-api' target='_blank'>here</a>
</span><br>
<br>
<b>All URLs are relative to (https://api.phoenixnap.com/tag-manager/v1/)</b>


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
For more information, please visit [https://phoenixnap.com/](https://phoenixnap.com/)

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

You can install this package directly from the [Python Package Index](https://pypi.org/) using:

```sh
$ pip install pnap_tag_api
```

Then import the package:
```python
import pnap_tag_api
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import pnap_tag_api
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import pnap_tag_api
from pprint import pprint
from pnap_tag_api.api import tags_api
from pnap_tag_api.model.delete_result import DeleteResult
from pnap_tag_api.model.error import Error
from pnap_tag_api.model.tag import Tag
from pnap_tag_api.model.tag_create import TagCreate
from pnap_tag_api.model.tag_update import TagUpdate
# Defining the host is optional and defaults to https://api.phoenixnap.com/tag-manager/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = pnap_tag_api.Configuration(
    host = "https://api.phoenixnap.com/tag-manager/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure OAuth2 access token for authorization: OAuth2
configuration = pnap_tag_api.Configuration(
    host = "https://api.phoenixnap.com/tag-manager/v1"
)
configuration.access_token = 'YOUR_ACCESS_TOKEN'


# Enter a context with an instance of the API client
with pnap_tag_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = tags_api.TagsApi(api_client)
    name = "env" # str | Query a tag by its name. (optional)

    try:
        # List tags.
        api_response = api_instance.tags_get(name=name)
        pprint(api_response)
    except pnap_tag_api.ApiException as e:
        print("Exception when calling TagsApi->tags_get: %s\n" % e)
```

To generate a token using the [python-keycloak](https://pypi.org/project/python-keycloak/) library:
```python
from keycloak import KeycloakOpenID

clientId = "YOUR_CLIENT_ID"
clientSecret = "YOUR_CLIENT_SECRET"
serverUrl = "https://auth.phoenixnap.com/auth/"
realmName = "BMC"
grantType = "client_credentials"

keycloakOpenId =  KeycloakOpenID(server_url=serverUrl,
                        realm_name=realmName,
                        client_id=clientId,
                        client_secret_key=clientSecret)

ACCESS_TOKEN = keycloakOpenId.token(grant_type=grantType)['access_token']
```

## Documentation for API Endpoints

All URIs are relative to *https://api.phoenixnap.com/tag-manager/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*TagsApi* | [**tags_get**](docs/TagsApi.md#tags_get) | **GET** /tags | List tags.
*TagsApi* | [**tags_post**](docs/TagsApi.md#tags_post) | **POST** /tags | Create a Tag.
*TagsApi* | [**tags_tag_id_delete**](docs/TagsApi.md#tags_tag_id_delete) | **DELETE** /tags/{tagId} | Delete a Tag.
*TagsApi* | [**tags_tag_id_get**](docs/TagsApi.md#tags_tag_id_get) | **GET** /tags/{tagId} | Get a Tag.
*TagsApi* | [**tags_tag_id_patch**](docs/TagsApi.md#tags_tag_id_patch) | **PATCH** /tags/{tagId} | Modify a Tag.


## Documentation For Models

 - [DeleteResult](docs/DeleteResult.md)
 - [Error](docs/Error.md)
 - [ResourceAssignment](docs/ResourceAssignment.md)
 - [Tag](docs/Tag.md)
 - [TagCreate](docs/TagCreate.md)
 - [TagUpdate](docs/TagUpdate.md)


## Documentation For Authorization


## OAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - **tags**: Grants full access to tags-api.
 - **tags.read**: Grants read only access to tags-api.


## Author

support@phoenixnap.com


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in pnap_tag_api.apis and pnap_tag_api.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from pnap_tag_api.api.default_api import DefaultApi`
- `from pnap_tag_api.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import pnap_tag_api
from pnap_tag_api.apis import *
from pnap_tag_api.models import *
```

